@@ -4,7 +4,7 @@
    Released under the Lesser Gnu Public License (LGPL) 3 or later
    See www.gnu.org for details
 
- (c) 2005 - 2009, Salsaman
+ (c) 2005 - 2011, Salsaman
 */
 
 
@@ -20,10 +20,17 @@
 
 ///////////////////////////////////////////////////////////////////
 
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed.h"
+#include "weed/weed-palettes.h"
+#include "weed/weed-effects.h"
+#include "weed/weed-plugin.h"
+#else
 #include "../../libweed/weed.h"
 #include "../../libweed/weed-palettes.h"
 #include "../../libweed/weed-effects.h"
 #include "../../libweed/weed-plugin.h"
+#endif
 
 ///////////////////////////////////////////////////////////////////
 
@@ -34,8 +41,13 @@ static int package_version=1; // version of this package
 
 //////////////////////////////////////////////////////////////////
 
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed-utils.h" // optional
+#include "weed/weed-plugin-utils.h" // optional
+#else
 #include "../../libweed/weed-utils.h" // optional
 #include "../../libweed/weed-plugin-utils.h" // optional
+#endif
 
 /////////////////////////////////////////////////////////////
 typedef f0r_instance_t (*f0r_construct_f)(unsigned int width, unsigned int height);
@@ -53,6 +65,30 @@ typedef void (*f0r_set_param_value_f)(f0r_instance_t *instance, f0r_param_t *par
 typedef void (*f0r_get_param_value_f)(f0r_instance_t *instance, f0r_param_t *param, int param_index);
 #endif
 
+// TODO
+#define MAX_PATH 4096
+
+
+static void getenv_piece(char * target, size_t tlen, char *envvar, int num) {
+  // get num piece from envvar path and set in target
+  char *str1;
+  memset(target,0,1);
+  
+  /* extract first string from string sequence */
+  str1 = strtok(envvar, ":");
+ 
+  /* loop until finishied */
+  while ( --num>=0 ) {
+    /* extract string from string sequence */
+    str1 = strtok(NULL, ":");
+      
+    /* check if there is nothing else to extract */
+    if (str1 == NULL) break;
+  }
+
+  if (str1!=NULL) snprintf(target,tlen,"%s",str1);
+
+}
 
 ////////////////////////////////////////////////////////////////
 
@@ -228,24 +264,24 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 
     int finished=0;
 
-    char *vdir1="/usr/lib/frei0r-1/";
-    char *vdir2="/usr/local/lib/frei0r-1/";
-    char vdir3[512];
+    char vdir1[MAX_PATH]="/usr/lib/frei0r-1/";
+    char vdir2[MAX_PATH]="/usr/local/lib/frei0r-1/";
+    char vdir3[MAX_PATH];
 
-    char dir1[512],dir2[512],dir3[512];
-    char plug1[512],plug2[512],plug3[512];
+    char dir1[MAX_PATH],dir2[MAX_PATH],dir3[MAX_PATH];
+    char plug1[MAX_PATH],plug2[MAX_PATH],plug3[MAX_PATH];
 
     struct dirent *vdirent=NULL,*dirent;
 
-    char homedir[256];
+    char homedir[MAX_PATH];
 
-    char vendor_name[256],plugin_name[256],weed_name[256];
+    char vendor_name[MAX_PATH],plugin_name[MAX_PATH],weed_name[MAX_PATH];
 
     DIR *curvdir=NULL,*curdir=NULL;
 
     int vdirval=0;
 
-    void *handle;
+    void *handle=NULL;
 
     int pversion;
 
@@ -266,58 +302,81 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
     f0r_param_color_t valcol;
     f0r_param_position_t valpos;
 
-    // quick and dirty fix for 64bit systems
-    char *fpp=getenv("FREI0R_PLUGIN_DIR");
-    if (fpp!=NULL) vdir2=fpp;
+#ifdef CAN_GET_DEF
+  f0r_instance_t f0r_inst;
+  f0r_get_param_value_f f0r_get_param_value=NULL;
+#endif
 
-    snprintf(homedir,256,"%s",getenv("HOME"));
-    snprintf (vdir3,256,"%s/frei0r-1/",homedir);
+    char *fpp=getenv("FREI0R_PATH");
+    if (fpp!=NULL) {
+      vdirval=10;
+    }
+    else {
+      snprintf(homedir,MAX_PATH,"%s",getenv("HOME"));
+      snprintf (vdir3,MAX_PATH,"%s/frei0r-1/",homedir);
+    }
 
-    while (vdirval<6) {
+    while (vdirval<6||vdirval>9) {
       // step through each of our frei0r dirs
       if (vdirval==0) {
 	curvdir=opendir(vdir3);
 	if (curvdir==NULL) vdirval=2;
 	else vdirval=1;
       }
-
+      
       if (vdirval==2) {
 	if (curvdir!=NULL) closedir(curvdir);
 	curvdir=opendir(vdir2);
 	if (curvdir==NULL) vdirval=4;
 	else vdirval=3;
       }
-
+      
       if (vdirval==4) {
 	if (curvdir!=NULL) closedir(curvdir);
 	curvdir=opendir(vdir1);
 	if (curvdir==NULL) {
 	  vdirval=6;
-	  continue;
+	  break;
 	}
 	vdirval=5;
       }
 
+      if (vdirval>9) {
+	getenv_piece(vdir1,MAX_PATH,fpp,vdirval-10);
+	if (!strlen(vdir1)) {
+	  vdirval=6;
+	  break;
+	}
+	curvdir=opendir(vdir1);
+	if (curvdir==NULL) {
+	  vdirval=6;
+	  break;
+	}
+      }
+      
       weed_memset(vendor_name,0,1);
-
-      do {
-
-	snprintf(dir1,512,"%s/%s",vdir1,vendor_name);
-	snprintf(dir2,512,"%s/%s",vdir2,vendor_name);
-	snprintf(dir3,512,"%s/%s",vdir3,vendor_name);
 	
-	vdirent=readdir(curvdir);
+	do {
 
-	if (vdirent==NULL) {
-	  closedir(curvdir);
-	  curvdir=NULL;
+	  snprintf(dir1,MAX_PATH,"%s/%s",vdir1,vendor_name);
+
+	  if (vdirval<10) {
+	    snprintf(dir2,MAX_PATH,"%s/%s",vdir2,vendor_name);
+	    snprintf(dir3,MAX_PATH,"%s/%s",vdir3,vendor_name);
+	  }
+
+	  vdirent=readdir(curvdir);
+	  
+	  if (vdirent==NULL) {
+	    closedir(curvdir);
+	    curvdir=NULL;
 	  vdirval++;
 	  break;
 	}
 
 	if (!strncmp(vdirent->d_name,"..",strlen(vdirent->d_name))) continue;
 
-	snprintf(vendor_name,256,"%s",vdirent->d_name);
+	snprintf(vendor_name,MAX_PATH,"%s",vdirent->d_name);
 
 	if (vdirval==1) {
 	  curdir=opendir(dir3);
@@ -328,14 +387,14 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	  curdir=opendir(dir2);
 	  if (curdir==NULL) continue;
 	}
-	else if (vdirval==5) {
+	else if (vdirval==5||vdirval>9) {
 	  if (curdir!=NULL) closedir(curdir);
 	  curdir=opendir(dir1);
 	  if (curdir==NULL) continue;
 	}
 
 	finished=0;
-
+	
 	while (!finished) {
 	  // step through our plugins
 	  dirent=readdir(curdir);
@@ -347,27 +406,30 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 
 	  if (!strncmp(dirent->d_name,"..",strlen(dirent->d_name))) continue;
 	  
-	  snprintf(plugin_name,256,"%s",dirent->d_name);
+	  snprintf(plugin_name,MAX_PATH,"%s",dirent->d_name);
 
-	  snprintf(plug1,512,"%s/%s",dir1,plugin_name);
-	  snprintf(plug2,512,"%s/%s",dir2,plugin_name);
-	  snprintf(plug3,512,"%s/%s",dir3,plugin_name);
+	  snprintf(plug1,MAX_PATH,"%s/%s",dir1,plugin_name);
 
-	  handle=dlopen(plug3,RTLD_NOW);
-	  if ((handle!=NULL&&(vdirval>1))||(handle==NULL&&vdirval==1)) {
-	    if (handle!=NULL) dlclose(handle);
-	    continue;
-	  }
-	  
-	  if (vdirval>1) {
-	    handle=dlopen(plug2,RTLD_NOW);
-	    if ((handle!=NULL&&(vdirval>3))||(handle==NULL&&vdirval==3)) {
+	  if (vdirval<10) {
+	    snprintf(plug2,MAX_PATH,"%s/%s",dir2,plugin_name);
+	    snprintf(plug3,MAX_PATH,"%s/%s",dir3,plugin_name);
+	    
+	    handle=dlopen(plug3,RTLD_NOW);
+	    if ((handle!=NULL&&(vdirval>1))||(handle==NULL&&vdirval==1)) {
 	      if (handle!=NULL) dlclose(handle);
 	      continue;
 	    }
+	    
+	    if (vdirval>1) {
+	      handle=dlopen(plug2,RTLD_NOW);
+	      if ((handle!=NULL&&(vdirval>3))||(handle==NULL&&vdirval==3)) {
+		if (handle!=NULL) dlclose(handle);
+		continue;
+	      }
+	    }
 	  }
-	  
-	  if (vdirval==5) {
+
+	  if (vdirval==5||vdirval>9) {
 	    handle=dlopen(plug1,RTLD_NOW);
 	    if (handle==NULL) continue;
 	  }
@@ -595,7 +657,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	      case F0R_PARAM_BOOL:
 		vald=0.;
 #ifdef CAN_GET_DEF
-		f0r_get_param_value(inst,&vald,pnum);
+		f0r_get_param_value(f0r_inst,(void **)&vald,pnum);
 #endif
 		in_params[wnum]=weed_switch_init((char *)pinfo.name,label,(int)vald);
 		weed_set_string_value(in_params[wnum],"description",(char *)pinfo.explanation);
@@ -604,7 +666,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	      case F0R_PARAM_DOUBLE:
 		vald=0.;
 #ifdef CAN_GET_DEF
-		f0r_get_param_value(inst,&vald,pnum);
+		f0r_get_param_value(f0r_inst,(void **)&vald,pnum);
 #endif
 		in_params[wnum]=weed_float_init((char *)pinfo.name,label,vald,0.,1.);
 		weed_set_string_value(in_params[wnum],"description",(char *)pinfo.explanation);
@@ -616,7 +678,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	      case F0R_PARAM_COLOR:
 		valcol.r=valcol.g=valcol.b=0.;
 #ifdef CAN_GET_DEF
-		f0r_get_param_value(inst,&valcol,pnum);
+		f0r_get_param_value(f0r_inst,(void **)&valcol,pnum);
 #endif
 		in_params[wnum]=weed_colRGBd_init((char *)pinfo.name,label,valcol.r,valcol.g,valcol.b);
 		weed_set_string_value(in_params[wnum],"description",(char *)pinfo.explanation);
@@ -625,7 +687,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	      case F0R_PARAM_POSITION:
 		valpos.x=valpos.y=0.;
 #ifdef CAN_GET_DEF
-		f0r_get_param_value(inst,&valpos,pnum);
+		f0r_get_param_value(f0r_inst,(void **)&valpos,pnum);
 #endif
 		in_params[wnum]=weed_float_init((char *)pinfo.name,label,valpos.x,0.,1.);
 		weed_set_string_value(in_params[wnum],"description",(char *)pinfo.explanation);
@@ -643,7 +705,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 		break;
 	      case F0R_PARAM_STRING:
 #ifdef CAN_GET_DEF
-		f0r_get_param_value(inst,&valch,pnum);
+		f0r_get_param_value(f0r_inst,(void **)&valch,pnum);
 #else
 		valch=strdup("Frei0r");
 #endif
@@ -679,7 +741,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	  f0r_destruct(f0r_inst);
 #endif
 
-	  snprintf(weed_name,256,"Frei0r: %s",f0rinfo.name);
+	  snprintf(weed_name,MAX_PATH,"Frei0r: %s",f0rinfo.name);
 	  pversion=f0rinfo.major_version*1000+f0rinfo.minor_version;
 
 	  filter_class=weed_filter_class_init(weed_name,(char *)f0rinfo.author,pversion,0,&frei0r_init,&frei0r_process,&frei0r_deinit,in_chantmpls,out_chantmpls,in_params,NULL);
@@ -709,6 +771,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 
 	  switch (f0rinfo.plugin_type) {
 	  case F0R_PLUGIN_TYPE_SOURCE:
+	    weed_set_double_value(filter_class,"target_fps",25.); // set reasonable default fps
 	  case F0R_PLUGIN_TYPE_FILTER:
 	    weed_set_voidptr_value(filter_class,"plugin_f0r_update",f0r_update);
 	    break;
@@ -723,7 +786,7 @@ weed_plant_t *weed_setup (weed_bootstrap_f weed_boot) {
 	// end vendor dir
       } while (vdirent!=NULL);
       if (curdir!=NULL) closedir(curdir);
-    }
+      }
     // end frei0r dirs
     if (curvdir!=NULL) closedir(curvdir);
 
