@@ -6,10 +6,17 @@
 // see file COPYING or www.gnu.org for details
 
 
-#include "../../libweed/weed.h"
-#include "../../libweed/weed-palettes.h"
-#include "../../libweed/weed-effects.h"
-#include "../../libweed/weed-plugin.h"
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed.h"
+#include "weed/weed-palettes.h"
+#include "weed/weed-effects.h"
+#include "weed/weed-plugin.h"
+#else
+#include "../../../libweed/weed.h"
+#include "../../../libweed/weed-palettes.h"
+#include "../../../libweed/weed-effects.h"
+#include "../../../libweed/weed-plugin.h"
+#endif
 
 ///////////////////////////////////////////////////////////////////
 
@@ -20,8 +27,13 @@ static int package_version=2; // version of this package
 
 //////////////////////////////////////////////////////////////////
 
-#include "../../libweed/weed-utils.h" // optional
-#include "../../libweed/weed-plugin-utils.h" // optional
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed-utils.h" // optional
+#include "weed/weed-plugin-utils.h" // optional
+#else
+#include "../../../libweed/weed-utils.h" // optional
+#include "../../../libweed/weed-plugin-utils.h" // optional
+#endif
 
 /////////////////////////////////////////////////////////////
 
@@ -256,7 +268,7 @@ int scribbler_process (weed_plant_t *inst, weed_timecode_t timestamp) {
           if((num_fonts_available) && (fontnum >= 0) && (fontnum < num_fonts_available) && (fonts_available[fontnum]))
             pango_font_description_set_family(font, fonts_available[fontnum]);
 
-          pango_font_description_set_absolute_size(font, font_size*PANGO_SCALE);
+          pango_font_description_set_size(font, font_size*PANGO_SCALE);
 
           pango_layout_set_font_description(layout, font);
           pango_layout_set_text(layout, text, -1);
