@@ -9,10 +9,17 @@
 #include <unistd.h>
 #include <stdlib.h>
 
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed.h"
+#include "weed/weed-palettes.h"
+#include "weed/weed-effects.h"
+#include "weed/weed-host.h"
+#else
 #include "../libweed/weed.h"
 #include "../libweed/weed-palettes.h"
 #include "../libweed/weed-effects.h"
 #include "../libweed/weed-host.h"
+#endif
 
 #include "main.h"
 #include "effects.h"
@@ -719,7 +726,7 @@ gboolean rte_on_off_callback (GtkAccelGroup *group, GObject *obj, guint keyval,
     }
   }
   if (mainw->current_file>0&&cfile->play_paused&&!mainw->noswitch) {
-    load_frame_image (cfile->frameno,cfile->last_frameno);
+    load_frame_image (cfile->frameno);
   }
   return TRUE;
 }
