@@ -63,24 +63,26 @@ POSSIBILITY OF SUCH DAMAGES.
 #include <signal.h>
 #include <assert.h>
 
-// don't change this unless the backend is changed as well
-// i.e. $GUI_BOOTSTRAP_FILE in smogrify
+/// don't change this unless the backend is changed as well
+/// i.e. $GUI_BOOTSTRAP_FILE in smogrify
 #define BOOTSTRAP_NAME "/tmp/.smogrify"
 
-// max files is actually 1 more than this, since file 0 is the clipboard
+/// max files is actually 1 more than this, since file 0 is the clipboard
 #define MAX_FILES 65535
 
-// this must match AC_PREFIX_DEFAULT in configure.in
-// TODO - when lives-plugins is a separate package, use pkg-config to get PREFIX and remove PREFIX_DEFAULT
+/// this must match AC_PREFIX_DEFAULT in configure.in
+/// TODO - when lives-plugins is a separate package, use pkg-config to get PREFIX and remove PREFIX_DEFAULT
 #ifndef PREFIX_DEFAULT
 #define PREFIX_DEFAULT "/usr"
 #endif
 
-// if --prefix= was not set, this is set to "NONE"
+/// if --prefix= was not set, this is set to "NONE"
 #ifndef PREFIX
 #define PREFIX PREFIX_DEFAULT
 #endif
 
+//#define HAVE_UNICAP 1
+
 #define DOC_DIR "/share/doc/lives-"
 
 #define THEME_DIR "/share/lives/themes/"
@@ -110,17 +112,17 @@ POSSIBILITY OF SUCH DAMAGES.
 #endif
 #endif
 
-// LiVES will show a warning if this (MBytes) is exceeded on load
-// (can be overridden in prefs)
+/// LiVES will show a warning if this (MBytes) is exceeded on load
+/// (can be overridden in prefs)
 #define WARN_FILE_SIZE 500
 
-// maximum fps we will allow (gdouble)
-// TODO - make pref
+/// maximum fps we will allow (gdouble)
+/// TODO - make pref
 #define FPS_MAX 200.
 
 #define ENABLE_DVD_GRAB
 
-#define FP_BITS 16 // max fp bits [apparently 16 is faster]
+#define FP_BITS 16 /// max fp bits [apparently 16 is faster]
 
 #ifdef HAVE_MJPEGTOOLS
 #define HAVE_YUV4MPEG
@@ -136,7 +138,11 @@ POSSIBILITY OF SUCH DAMAGES.
 #define LIVES_INLINE
 #endif
 
+#include <limits.h>
 
+#ifndef PATH_MAX
+#define PATH_MAX 4096
+#endif
 
 #ifdef __GNUC__
 #  define WARN_UNUSED  __attribute__((warn_unused_result))
@@ -146,8 +152,8 @@ POSSIBILITY OF SUCH DAMAGES.
 
 
 
-// this struct is used only when physically resampling frames on the disk
-// we create an array of these and write them to the disk
+/// this struct is used only when physically resampling frames on the disk
+/// we create an array of these and write them to the disk
 typedef struct {
   gint value;
   gint64 reltime;
@@ -183,31 +189,8 @@ typedef struct {
 // see weed event spec. for more info
 
 
-typedef union {
-  float **floatbuf; // float data - for jack
-  short *int16buf; // 16 bit int - for pulse audio
-} adata;
 
-
-typedef struct {
-
-  int achans;
-  int arate;
-
-  weed_timecode_t start_tc;
-
-  volatile size_t start_sample;  // current read posn
-
-  adata data;
-
-  volatile size_t samples_filled; // number of samples filled (usable)
-  size_t sample_space; // total space
-} lives_audio_buf_t;
-
-
-
-
-// need this for event_list_t *
+/// need this for event_list_t *
 #include "events.h"
 
 
@@ -228,22 +211,22 @@ typedef enum {
   UNDO_INSERT_SILENCE,
   UNDO_NEW_AUDIO,
 
-  // resample/resize and resample audio for encoding
+  /// resample/resize and resample audio for encoding
   UNDO_ATOMIC_RESAMPLE_RESIZE,
 
-  // resample/reorder/resize/apply effects
+  /// resample/reorder/resize/apply effects
   UNDO_RENDER,
 
   UNDO_FADE_AUDIO,
 
-  // record audio to selection
+  /// record audio to selection
   UNDO_REC_AUDIO,
 
   UNDO_INSERT_WITH_AUDIO
 } lives_undo_t;
 
 
-// which stream end should cause playback to finish ?
+/// which stream end should cause playback to finish ?
 typedef enum {
   NEVER_STOP=0,
   STOP_ON_VID_END,
@@ -251,70 +234,71 @@ typedef enum {
 } lives_whentostop_t;
 
 
-// cancel reason
+/// cancel reason
 typedef enum {
-  // no cancel
+  /// no cancel
   CANCEL_NONE=0,
 
-  // user pressed stop
+  /// user pressed stop
   CANCEL_USER=1,
 
-  // cancel but keep opening
+  /// cancel but keep opening
   CANCEL_NO_PROPOGATE=2,
 
-  // effect processing finished during preview
+  /// effect processing finished during preview
   CANCEL_PREVIEW_FINISHED=3,
 
-  // application quit
+  /// application quit
   CANCEL_APP_QUIT=4,
 
-  // ran out of preview frames
+  /// ran out of preview frames
   CANCEL_NO_MORE_PREVIEW=5,
 
-  // image could not be captured
+  /// image could not be captured
   CANCEL_CAPTURE_ERROR=6,
 
-  // event_list completed
+  /// event_list completed
   CANCEL_EVENT_LIST_END=7,
 
-  // video playback completed
+  /// video playback completed
   CANCEL_VID_END=8,
 
-  // generator was stopped
+  /// generator was stopped
   CANCEL_GENERATOR_END=9,
 
-  // user pressed 'Keep'
+  /// user pressed 'Keep'
   CANCEL_KEEP=10,
 
-  // video playback completed
+  /// video playback completed
   CANCEL_AUD_END=11,
 
-  // cancelled because of error
+  /// cancelled because of error
   CANCEL_ERROR=12,
 
-  // cancelled and paused
+  /// cancelled and paused
   CANCEL_USER_PAUSED=13,
 
-  // special cancel for TV toy
+  /// special cancel for TV toy
   CANCEL_KEEP_LOOPING=100
 
 } lives_cancel_t;
 
 
 typedef enum {
-  CANCEL_KILL=0,  // normal - kill background processes working on current clip
-  CANCEL_SOFT     // just cancel in GUI (for keep, etc)
+  CANCEL_KILL=0,  ///< normal - kill background processes working on current clip
+  CANCEL_SOFT     ///< just cancel in GUI (for keep, etc)
 } lives_cancel_type_t;
 
 
 
 
 typedef enum {
-  CLIP_TYPE_DISK, // imported video, broken into frames
-  CLIP_TYPE_YUV4MPEG,
-  CLIP_TYPE_GENERATOR,
-  CLIP_TYPE_FILE, // unimported video, not or partially broken in frames
-  CLIP_TYPE_LIVES2LIVES // type for LiVES to LiVES streaming
+  CLIP_TYPE_DISK, ///< imported video, broken into frames
+  CLIP_TYPE_YUV4MPEG, ///< yuv4mpeg stream
+  CLIP_TYPE_GENERATOR, ///< frames from generator plugin
+  CLIP_TYPE_FILE, ///< unimported video, not or partially broken in frames
+  CLIP_TYPE_LIVES2LIVES, ///< type for LiVES to LiVES streaming
+  CLIP_TYPE_VIDEODEV  ///< frames from video device
 } lives_clip_type_t;
 
 
@@ -348,21 +332,27 @@ typedef struct {
 } lives_colRGBA32_t;
 
 
+typedef enum {
+  LIVES_INTERLACE_NONE=0,
+  LIVES_INTERLACE_BOTTOM_FIRST=1,
+  LIVES_INTERLACE_TOP_FIRST=2
+} lives_interlace_t;
+
+
 #include "pangotext.h"
 
-typedef struct {                // corresponds to one clip in the GUI
-  // cfile - one clip
-  //
+/// corresponds to one clip in the GUI
+typedef struct {
   // basic info (saved during backup)
   gint bpp;
   gdouble fps;
-  gint hsize; // in pixels (NOT macropixels !)
+  gint hsize; ///< in pixels (NOT macropixels !)
   gint vsize;
-  gint arps; // audio sample rate
-  guint signed_endian; // bitfield
+  gint arps; ///< audio sample rate
+  guint signed_endian; ///< bitfield
 
-  gint arate; // audio playback rate
-  gint64 unique_id;    // this and the handle can be used to uniquely id a file
+  gint arate; ///< audio playback rate
+  gint64 unique_id;    ///< this and the handle can be used to uniquely id a file
   gint achans;
   gint asampsize;
 
@@ -374,7 +364,7 @@ typedef struct {                // corresponds to one clip in the GUI
   gchar keywords[256];
   ////////////////
 
-  gint interlace; // interlace type (if known - none, topfirst, bottomfirst or : see plugins.h)
+  lives_interlace_t interlace; ///< interlace type (if known - none, topfirst, bottomfirst or : see plugins.h)
 
   // extended info (not saved)
   gint header_version;
@@ -383,7 +373,7 @@ typedef struct {                // corresponds to one clip in the GUI
 
   gint rowstride;
 
-  // the processing window
+  /// the processing window
   process *proc_ptr;
 
   gchar handle[256];
@@ -391,10 +381,10 @@ typedef struct {                // corresponds to one clip in the GUI
   gint ovsize;
   glong f_size;
   glong afilesize;
-  gint old_frames; // for deordering, etc.
-  gchar file_name[256]; // input file
+  gint old_frames; ///< for deordering, etc.
+  gchar file_name[256]; ///< input file
   gchar info_file[256];
-  gchar name[256];  // the display name
+  gchar name[256];  ///< the display name
   gchar save_file_name[256];
   gchar type[40];
   gint start;
@@ -418,12 +408,12 @@ typedef struct {                // corresponds to one clip in the GUI
   gboolean opening_only_audio;
   gboolean opening_loc;
   gboolean restoring;
-  gboolean is_loaded;  // should we continue loading if we come back to this clip
+  gboolean is_loaded;  ///< should we continue loading if we come back to this clip
 
-  // don't show preview/pause buttons on processing
+  /// don't show preview/pause buttons on processing
   gboolean nopreview;
 
-  // don't show the 'keep' button - e.g. for operations which resize frames
+  /// don't show the 'keep' button - e.g. for operations which resize frames
   gboolean nokeep;
 
   // various times; total time is calculated as the gint64est of video, laudio and raudio
@@ -444,7 +434,7 @@ typedef struct {                // corresponds to one clip in the GUI
 
 
   // events 
-  event *events[1];  //for block resampler
+  event *events[1];  ///<for block resampler
 
   weed_plant_t *event_list;
   weed_plant_t *event_list_back;
@@ -453,7 +443,7 @@ typedef struct {                // corresponds to one clip in the GUI
   GList *layout_map;
   ////////////////////////////////////////////////////////////////////////////////////////
 
-  //undo
+  ///undo
   lives_undo_t undo_action;
 
   gint undo_start;
@@ -475,43 +465,44 @@ typedef struct {                // corresponds to one clip in the GUI
   gboolean undo2_boolean;
   gboolean undo3_boolean;
 
-  gint undo_arate; // audio playback rate
+  gint undo_arate; ///< audio playback rate
   guint undo_signed_endian;
   gint undo_achans;
   gint undo_asampsize;
-  gint undo_arps; // audio sample rate
+  gint undo_arps; ///< audio sample rate
 
   lives_clip_type_t clip_type;
 
-  void *ext_src; // points to opaque source for non-disk types
+  void *ext_src; ///< points to opaque source for non-disk types
 
-  int *frame_index; // index of frames for CLIP_TYPE_FILE
-  // >0 means corresponding frame within original clip
-  // -1 means corresponding image file (equivalent to CLIP_TYPE_DISK)
-  // size must be >= frames, MUST be contiguous in memory
+  /// index of frames for CLIP_TYPE_FILE
+  /// >0 means corresponding frame within original clip
+  /// -1 means corresponding image file (equivalent to CLIP_TYPE_DISK)
+  /// size must be >= frames, MUST be contiguous in memory
+  int *frame_index;
 
-  int *frame_index_back; // for undo
+  int *frame_index_back; ///< for undo
 
-  gint fx_frame_pump; // rfx frame pump for virtual clips (CLIP_TYPE_FILE)
+  gint fx_frame_pump; ///< rfx frame pump for virtual clips (CLIP_TYPE_FILE)
 
-#define FX_FRAME_PUMP_VAL 100 // how many frames at a time to pump to rfx
+#define FX_FRAME_PUMP_VAL 100 ///< how many frames at a time to pump to rfx
 
-#define IMG_BUFF_SIZE 4096 // chunk size for reading images
+#define IMG_BUFF_SIZE 4096 ///< chunk size for reading images
 
-  gboolean ratio_fps; // if the fps was set by a ratio
+  gboolean ratio_fps; ///< if the fps was set by a ratio
 
-  glong aseek_pos; // audio seek posn. (bytes) for when we switch clips
+  glong aseek_pos; ///< audio seek posn. (bytes) for when we switch clips
 
   // decoder data
 
   gchar mime_type[256];
 
 
-  gboolean deinterlace;
+  gboolean deinterlace; ///< auto deinterlace
 
   lives_image_type_t img_type;
 
-  // layout map for the current layout
+  /// layout map for the current layout
   gint stored_layout_frame;
   gint stored_layout_idx;
   gdouble stored_layout_audio;
@@ -546,10 +537,10 @@ typedef struct {
   gboolean has_xwininfo;
   gboolean has_gdb;
 
-  // home directory - default location for config file - locale encoding
+  /// home directory - default location for config file - locale encoding
   gchar home_dir[256];
 
-  // used for returning startup messages from the backend
+  /// used for returning startup messages from the backend
   gchar startup_msg[256];
 
   // plugins
@@ -567,14 +558,10 @@ typedef struct {
 } capability;
 
 
-// some shared structures
-capability *capable;
+/// some shared structures
+extern capability *capable;
 
 #ifdef HAVE_JACK_JACK_H
-
-#ifdef HAVE_JACK_TRANSPORT_H
-#endif
-
 #include "jack.h"
 #endif
 
@@ -589,7 +576,7 @@ capability *capable;
 #include "keyboard.h"
 #include "preferences.h"
 
-mainwindow *mainw;
+extern mainwindow *mainw;
 
 
 // internal player clock
@@ -597,8 +584,8 @@ mainwindow *mainw;
 struct timeval tv;
 
 
-// type sizes
-size_t sizint, sizdbl, sizshrt;
+/// type sizes
+extern size_t sizint, sizdbl, sizshrt;
 
 
 
@@ -629,7 +616,7 @@ typedef enum {
 
 
 typedef enum {
-  LIVES_CURSOR_NORMAL=0,  // must be zero
+  LIVES_CURSOR_NORMAL=0,  ///< must be zero
   LIVES_CURSOR_BLOCK,
   LIVES_CURSOR_AUDIO_BLOCK,
   LIVES_CURSOR_BUSY,
@@ -664,6 +651,7 @@ gboolean do_progress_dialog(gboolean visible, gboolean cancellable, const gchar
 gboolean do_warning_dialog(const gchar *text);
 gboolean do_warning_dialog_with_check(const gchar *text, gint warn_mask_number);
 gboolean do_warning_dialog_with_check_transient(const gchar *text, gint warn_mask_number, GtkWindow *transient);
+gboolean do_yesno_dialog(const gchar *text);
 void do_error_dialog(const gchar *text);
 void do_error_dialog_with_check(const gchar *text, gint warn_mask_number);
 void do_blocking_error_dialog(const gchar *text);
@@ -718,6 +706,7 @@ void do_no_decoder_error(const gchar *fname);
 void do_jack_noopen_warn(void);
 void do_jack_noopen_warn2(void);
 void do_jack_noopen_warn3(void);
+void do_jack_noopen_warn4(void);
 void do_file_perm_error(const gchar *file_name);
 void do_dir_perm_error(const gchar *dir_name);
 void do_encoder_img_ftm_error(render_details *rdet);
@@ -729,6 +718,11 @@ gboolean do_existing_subs_warning(void);
 void do_invalid_subs_error(void);
 gboolean do_erase_subs_warning(void);
 gboolean do_sub_type_warning(const gchar *ext, const gchar *type_ext);
+gboolean do_move_tmpdir_dialog(void);
+void do_set_locked_warning (const gchar *setname);
+void do_no_in_vdevs_error(void);
+void do_locked_in_vdevs_error(void);
+void do_do_not_close_d (void);
 
 gboolean process_one (gboolean visible);
 void do_threaded_dialog(const gchar *text, gboolean has_cancel);
@@ -750,7 +744,7 @@ void d_print_file_error_failed(void);
 void do_text_window (const gchar *title, const gchar *text);
 
 // saveplay.c
-void add_file_info(const gchar *check_handle, gboolean aud_only);
+gboolean add_file_info(const gchar *check_handle, gboolean aud_only);
 void save_file_comments (int fileno);
 void reget_afilesize (int fileno);
 void deduce_file(const gchar *filename, gdouble start_time, gint end);
@@ -763,7 +757,7 @@ void get_handle_from_info_file(gint index);
 void create_cfile(void);
 void save_file (gboolean existing, gchar *n_file_name);
 void play_file (void);
-gboolean save_frame(gint frame, const gchar *filename);
+gboolean save_frame(gint clip, gint frame, const gchar *file_name, gint width, gint height);
 void wait_for_stop (const gchar *stop_command);
 void save_clip_values(gint which_file);
 void add_to_recovery_file (const gchar *handle);
@@ -807,11 +801,11 @@ gboolean pull_frame(weed_plant_t *layer, const gchar *image_ext, weed_timecode_t
 gboolean pull_frame_at_size (weed_plant_t *layer, const gchar *image_ext, weed_timecode_t tc, int width, int height, int target_palette);
 GdkPixbuf *pull_gdk_pixbuf_at_size(gint clip, gint frame, const gchar *image_ext, weed_timecode_t tc, gint width, gint height, GdkInterpType interp);
 
-void load_frame_image(gint frame, gint last_frame);
+void load_frame_image(gint frame);
 void sensitize(void);
 void desensitize(void);
 void procw_desensitize(void);
-void close_current_file (gint file_to_switch_to);  // close current file, and try to switch to file_to_switch_to
+void close_current_file (gint file_to_switch_to);  ///< close current file, and try to switch to file_to_switch_to
 void get_next_free_file(void);
 void switch_to_file(gint old_file, gint new_file);
 void do_quick_switch (gint new_file);
@@ -879,7 +873,7 @@ guint get_signed_endian (gboolean is_signed, gboolean little_endian);
 void fullscreen_internal(void);
 void unhide_cursor(GdkWindow *window);
 void hide_cursor(GdkWindow *window);
-void set_alwaysontop(GtkWidget *window, gboolean ontop); // TODO - use for playwin
+void set_alwaysontop(GtkWidget *window, gboolean ontop); ///< TODO - use for playwin
 void colour_equal(GdkColor *c1, const GdkColor *c2);
 void switch_to_int_player(void);
 void switch_to_mplayer(void);
@@ -889,21 +883,22 @@ gboolean switch_aud_to_pulse(void);
 void switch_aud_to_mplayer(void);
 void prepare_to_play_foreign(void);
 gboolean after_foreign_play(void);
-gboolean check_file(const gchar *file_name, gboolean check_exists);  // check if file exists
+gboolean check_file(const gchar *file_name, gboolean check_exists);  ///< check if file exists
 gboolean check_dir_access (const gchar *dir);
 gulong get_file_size(int fd);
 gulong sget_file_size(const gchar *name);
 gulong get_fs_free(const gchar *dir);
 gboolean ensure_isdir(gchar *fname);
 gchar *ensure_extension(const gchar *fname, const gchar *ext) WARN_UNUSED;
+gboolean check_dev_busy(gchar *devstr);
 void activate_url_inner(const gchar *link);
 void activate_url (GtkAboutDialog *about, const gchar *link, gpointer data);
 void show_manual_section (const gchar *lang, const gchar *section);
 
 LIVES_INLINE gdouble calc_time_from_frame (gint clip, gint frame);
-LIVES_INLINE gint calc_frame_from_time (gint filenum, gdouble time);  // nearest frame start
-LIVES_INLINE gint calc_frame_from_time2 (gint filenum, gdouble time); // nearest frame end
-LIVES_INLINE gint calc_frame_from_time3 (gint filenum, gdouble time); // nearest frame mid
+LIVES_INLINE gint calc_frame_from_time (gint filenum, gdouble time);  ///< nearest frame start
+LIVES_INLINE gint calc_frame_from_time2 (gint filenum, gdouble time); ///< nearest frame end
+LIVES_INLINE gint calc_frame_from_time3 (gint filenum, gdouble time); ///< nearest frame mid
 
 gboolean check_for_ratio_fps (gdouble fps);
 gdouble get_ratio_fps(const gchar *string);
@@ -972,11 +967,6 @@ void lives_set_cursor_style(lives_cursor_t cstyle, GdkWindow *window);
 gchar *text_view_get_text(GtkTextView *textview);
 void text_view_set_text(GtkTextView *textview, const gchar *text);
 
-
-
-// effects.c
-void invalidate_pixel_buffers (void); // TODO - exterminate !
-
 // plugins.c
 GList *get_external_window_hints(lives_rfx_t *rfx);
 gboolean check_encoder_restrictions (gboolean get_extension, gboolean user_audio);
@@ -1013,6 +1003,9 @@ gboolean lives_osc_init(guint osc_udp_port);
 gint lives_osc_poll(gpointer data);
 void lives_osc_end(void);
 gboolean lives_osc_notify(int msgtype, const char *msgstring);
+void lives_osc_notify_success (const gchar *msg);
+void lives_osc_notify_failure (void);
+void lives_osc_notify_cancel (void);
 #include "osc_notify.h"
 #endif
 
@@ -1036,8 +1029,9 @@ char *dummychar;
 #define L2U8(String) ( g_locale_to_utf8 (String,-1,NULL,NULL,NULL) ) 
 
 
-#define PREFS_TIMEOUT 10000000 // 10 seconds // TODO !
+#define PREFS_TIMEOUT 10000000 ///< 10 seconds // TODO !
 
 #define LIVES_TV_CHANNEL1 "http://www.serverwillprovide.com/sorteal/livestvclips/livestv.ogm"
 
+
 #endif // #ifndef HAS_MAIN_H
