@@ -7,11 +7,19 @@
 #include <dlfcn.h>
 #include <errno.h>
 
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed.h"
+#include "weed/weed-palettes.h"
+#include "weed/weed-effects.h"
+#include "weed/weed-utils.h"
+#include "weed/weed-host.h"
+#else
 #include "../libweed/weed.h"
 #include "../libweed/weed-palettes.h"
 #include "../libweed/weed-effects.h"
 #include "../libweed/weed-utils.h"
 #include "../libweed/weed-host.h"
+#endif
 
 #include "main.h"
 #include "resample.h"
@@ -200,7 +208,7 @@ GList *get_plugin_list (const gchar *plugin_type, gboolean allow_nonex, const gc
   // allow_nonex to allow non-executable files (e.g. libs)
   // filter_ext can be non-NULL to filter for files ending .filter_ext
 
-  // TODO - use numbers for plugin_type ?
+  // TODO - use enum for plugin_type
 
   gchar *com,*tmp;
   GList *pluglist;
@@ -338,7 +346,10 @@ void load_vpp_defaults(_vid_playback_plugin *vpp) {
   int i;
   gchar *msg;
 
-  if (!g_file_test(vpp_file,G_FILE_TEST_EXISTS)) return;
+  if (!g_file_test(vpp_file,G_FILE_TEST_EXISTS)) {
+    g_free(vpp_file);
+    return;
+  }
 
   msg=g_strdup_printf(_("Loading video playback plugin defaults from %s..."),vpp_file);
   d_print(msg);
@@ -360,6 +371,7 @@ void load_vpp_defaults(_vid_playback_plugin *vpp) {
   if (strcmp(msg,buf)) {
     g_free(msg);
     d_print_file_error_failed();
+    g_free(vpp_file);
     return;
   }
   g_free(msg);
@@ -371,6 +383,7 @@ void load_vpp_defaults(_vid_playback_plugin *vpp) {
 
   if (strcmp(buf,mainw->vpp->name)) {
     d_print_failed();
+    g_free(vpp_file);
     return;
   }
 
@@ -696,7 +709,7 @@ _vppaw *on_vpp_advanced_clicked (GtkButton *button, gpointer user_data) {
 
   vppa->dialog = gtk_dialog_new ();
 
-  if (prefsw!=NULL) gtk_widget_hide (prefsw->prefs_dialog);
+  //if (prefsw!=NULL) gtk_widget_hide (prefsw->prefs_dialog);
 
   gtk_window_set_position (GTK_WINDOW (vppa->dialog), GTK_WIN_POS_CENTER);
   if (!prefs->show_gui) {
@@ -767,9 +780,16 @@ _vppaw *on_vpp_advanced_clicked (GtkButton *button, gpointer user_data) {
     
     nfps=get_token_count((gchar *)fps_list,'|');
     for (i=0;i<nfps;i++) {
-      if (strlen(array[i])&&strcmp(array[i],"\n")) fps_list_strings=g_list_append (fps_list_strings, array[i]);
+      if (strlen(array[i])&&strcmp(array[i],"\n")) {
+	if (get_token_count(array[i],':')==0) {
+	  fps_list_strings=g_list_append (fps_list_strings, remove_trailing_zeroes(g_strtod(array[i],NULL)));
+	}
+	else fps_list_strings=g_list_append (fps_list_strings,g_strdup(array[i]));
+      }
     }
+
     combo_set_popdown_strings (GTK_COMBO (combo), fps_list_strings);
+    g_list_free_strings(fps_list_strings);
     g_list_free(fps_list_strings);
     fps_list_strings=NULL;
     g_strfreev (array);
@@ -973,7 +993,7 @@ _vid_playback_plugin *open_vid_playback_plugin (const gchar *name, gboolean usin
 
   if (handle==NULL) {
     gchar *msg=g_strdup_printf (_("\n\nFailed to open playback plugin %s\nError was %s\n"),plugname,dlerror());
-    if (prefsw!=NULL) do_error_dialog_with_check_transient(msg,TRUE,0,GTK_WINDOW(prefsw->prefs_dialog));
+    if (prefsw!=NULL) do_error_dialog_with_check_transient(msg,TRUE,0,prefsw!=NULL?GTK_WINDOW(prefsw->prefs_dialog):GTK_WINDOW(mainw->LiVES->window));
     else do_error_dialog(msg);
     g_free (msg);
     g_free(plugname);
@@ -1008,7 +1028,7 @@ _vid_playback_plugin *open_vid_playback_plugin (const gchar *name, gboolean usin
 
   if ((pl_error=(*vpp->module_check_init)())!=NULL) {
     msg=g_strdup_printf(_("Video playback plugin failed to initialise.\nError was: %s\n"),pl_error);
-    do_error_dialog_with_check_transient(msg,FALSE,0,GTK_WINDOW(prefsw->prefs_dialog));
+    do_error_dialog_with_check_transient(msg,TRUE,0,prefsw!=NULL?GTK_WINDOW(prefsw->prefs_dialog):GTK_WINDOW(mainw->LiVES->window));
     g_free(msg);
     dlclose (handle);
     g_free (vpp);
@@ -1020,7 +1040,7 @@ _vid_playback_plugin *open_vid_playback_plugin (const gchar *name, gboolean usin
   if (!OK) {
     gchar *msg=g_strdup_printf (_("\n\nPlayback module %s\nis missing a mandatory function.\nUnable to use it.\n"),plugname);
     set_pref ("vid_playback_plugin","none");
-    do_error_dialog_with_check_transient(msg,FALSE,0,GTK_WINDOW(prefsw->prefs_dialog));
+    do_error_dialog_with_check_transient(msg,TRUE,0,prefsw!=NULL?GTK_WINDOW(prefsw->prefs_dialog):GTK_WINDOW(mainw->LiVES->window));
     g_free (msg);
     close_vid_playback_plugin(vpp);
     g_free(plugname);
@@ -1206,6 +1226,9 @@ void vid_playback_plugin_exit (void) {
   }
   mainw->stream_ticks=-1;
   mainw->ext_keyboard=FALSE;
+
+  if (mainw->playing_file>-1&&mainw->fs&&mainw->sep_win) gtk_window_fullscreen(GTK_WINDOW(mainw->play_window));
+  gtk_window_set_title (GTK_WINDOW (mainw->play_window),_("LiVES: - Play Window"));
 }
 
 ///////////////////////
@@ -1239,7 +1262,7 @@ gboolean check_encoder_restrictions (gboolean get_extension, gboolean user_audio
   gboolean calc_aspect=FALSE;
   gchar aspect_buffer[512];
   gint hblock=2,vblock=2;
-  int i,r;
+  int i,r,val;
   GList *ofmt_all=NULL;
   gboolean sizer=FALSE;
 
@@ -1432,7 +1455,38 @@ gboolean check_encoder_restrictions (gboolean get_extension, gboolean user_audio
 	continue;
       }
       
-      
+      if (!strncmp (checks[r],"minw=",5)) {
+	array=g_strsplit(checks[r],"=",2);
+	val=atoi(array[1]);
+	if (width<val) width=val;
+	g_strfreev(array);
+	continue;
+      }
+
+      if (!strncmp (checks[r],"minh=",5)) {
+	array=g_strsplit(checks[r],"=",2);
+	val=atoi(array[1]);
+	if (height<val) height=val;
+	g_strfreev(array);
+	continue;
+      }
+
+      if (!strncmp (checks[r],"maxh=",5)) {
+	array=g_strsplit(checks[r],"=",2);
+	val=atoi(array[1]);
+	if (height>val) height=val;
+	g_strfreev(array);
+	continue;
+      }
+
+      if (!strncmp (checks[r],"maxw=",5)) {
+	array=g_strsplit(checks[r],"=",2);
+	val=atoi(array[1]);
+	if (width>val) width=val;
+	g_strfreev(array);
+	continue;
+      }
+
       
       if (!strncmp (checks[r],"asigned=",8)&&((mainw->save_with_sound||rdet!=NULL)&&(resaudw==NULL||resaudw->aud_checkbutton==NULL||gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(resaudw->aud_checkbutton))))&&prefs->encoder.audio_codec!=AUDIO_CODEC_NONE&&(arate*achans*asampsize)) {
 	array=g_strsplit(checks[r],"=",2);
@@ -1555,6 +1609,17 @@ gboolean check_encoder_restrictions (gboolean get_extension, gboolean user_audio
   }
 
 
+
+  // if we have min or max size, make sure we fit within that
+
+
+
+
+
+
+
+
+
   if (((width!=owidth||height!=oheight)&&width*height>0)||(best_fps_delta>0.)||(best_arate_delta>0&&best_arate>0)||best_arate<0||asigned!=0) {
     gboolean ofx1_bool=mainw->fx1_bool;
     mainw->fx1_bool=FALSE;
@@ -1634,18 +1699,42 @@ GList *filter_encoders_by_img_ext(GList *encoders, const gchar *img_ext) {
   GList *encoder_capabilities=NULL;
   GList *list=encoders,*listnext;
   int caps;
+  char *blacklist[]={
+    NULL
+  };
 
   if (!strcmp(img_ext,"jpg")) return encoders; // jpeg is the default
 
   while (list!=NULL) {
+    gboolean skip=FALSE;
+    int i=0;
+
     listnext=list->next;
+
+    while (blacklist[i++]!=NULL) {
+      if (strlen(list->data)==strlen(blacklist[i])&&!strcmp(list->data,blacklist[i])) {
+	// skip blacklisted encoders
+	g_free(list->data);
+	encoders=g_list_delete_link(encoders,list);
+	skip=TRUE;
+	break;
+      }
+      i++;
+    }
+    if (skip) {
+      list=listnext;
+      continue;
+    }
+
     if ((encoder_capabilities=plugin_request(PLUGIN_ENCODERS,list->data,"get_capabilities"))==NULL) {
+      g_free(list->data);
       encoders=g_list_delete_link(encoders,list);
     }
     else {
       caps=atoi (g_list_nth_data (encoder_capabilities,0));
       
       if (!(caps&CAN_ENCODE_PNG)&&!strcmp(img_ext,"png")) {
+	g_free(list->data);
 	encoders=g_list_delete_link(encoders,list);
       }
 
@@ -2796,6 +2885,7 @@ lives_rfx_t *weed_to_rfx (weed_plant_t *plant, gboolean show_reinits) {
   else {
     filter=plant;
     plant=weed_instance_from_filter(filter);
+    // init and deinit the effect to allow the plugin to hide parameters, etc.
     weed_reinit_effect(plant,FALSE);
     rfx->is_template=TRUE;
   }
@@ -2943,6 +3033,9 @@ gchar *plugin_run_param_window(const gchar *get_com, GtkVBox *vbox, lives_rfx_t
 
     rfx->menu_text=(vbox==NULL?g_strdup_printf(_("%s advanced settings"),prefs->encoder.of_desc):g_strdup(""));
     rfx->is_template=FALSE;
+
+    rfx->source=NULL;
+    rfx->source_type=LIVES_RFX_SOURCE_RFX;
       
     render_fx_get_params(rfx,rfx_scrapname,RFX_STATUS_SCRAP);
 
