@@ -8,8 +8,13 @@
 #include <errno.h>
 #include <sys/stat.h>
 
+#ifdef HAVE_SYSTEM_WEED
+#include "weed/weed.h"
+#include "weed/weed-host.h"
+#else
 #include "../libweed/weed.h"
 #include "../libweed/weed-host.h"
+#endif
 
 #include "main.h"
 
@@ -130,7 +135,7 @@ static void save_keymap2_file(gchar *kfname) {
     for (j=0;j<modes;j++) {
       if (rte_keymode_valid(i,j,TRUE)) {
 	dummyvar=write(kfd,&i,sizint);
-	hashname=g_strdup_printf("Weed%s",make_weed_hashname(rte_keymode_get_filter_idx(i,j)));
+	hashname=g_strdup_printf("Weed%s",make_weed_hashname(rte_keymode_get_filter_idx(i,j),TRUE));
 	slen=strlen(hashname);
 	dummyvar=write(kfd,&slen,sizint);
 	dummyvar=write(kfd,hashname,slen);
@@ -190,7 +195,7 @@ gboolean on_save_keymap_clicked (GtkButton *button, gpointer user_data) {
     for (i=1;i<=prefs->rte_keys_virtual;i++) {
       for (j=0;j<modes;j++) {
 	if (rte_keymode_valid(i,j,TRUE)) {
-	  fputs(g_strdup_printf("%d|Weed%s\n",i,make_weed_hashname(rte_keymode_get_filter_idx(i,j))),kfile);
+	  fputs(g_strdup_printf("%d|Weed%s\n",i,make_weed_hashname(rte_keymode_get_filter_idx(i,j),TRUE)),kfile);
 	}
       }
     }
@@ -376,11 +381,12 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
   int i;
   int kfd;
   int version,nparams;
+  int hlen;
   FILE *kfile=NULL;
   gchar *msg,*tmp;
   gint key,mode;
   gchar buff[65536];
-  size_t linelen,bytes,hlen;
+  size_t linelen,bytes;
   gchar *whole=g_strdup (""),*whole2;
   GList *list=NULL,*new_list=NULL;
   gchar *hashname,*hashname_new=NULL;
@@ -394,6 +400,11 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
   gchar *keymap_file=g_build_filename(capable->home_dir,LIVES_CONFIG_DIR,"default.keymap",NULL);
   gchar *keymap_file2=g_build_filename(capable->home_dir,LIVES_CONFIG_DIR,"default.keymap2",NULL);
 
+  int *def_modes;
+
+  def_modes=(int *)g_malloc(prefs->rte_keys_virtual*sizint);
+  for (i=0;i<prefs->rte_keys_virtual;i++) def_modes[i]=-1;
+
   if ((kfd=open (keymap_file2,O_RDONLY))!=-1) {
     g_free(keymap_file);
     keymap_file=keymap_file2;
@@ -422,6 +433,7 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
     do_error_dialog_with_check_transient (msg,FALSE,0,GTK_WINDOW(rte_window));
     g_free (msg);
     d_print_failed();
+    g_free(def_modes);
     return FALSE;
   }
 
@@ -429,6 +441,7 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
   if (mainw->error) {
     mainw->error=FALSE;
     d_print_cancelled();
+    g_free(def_modes);
     return FALSE;
   }
 
@@ -448,7 +461,6 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
 	}
       }
     }
-    g_free (whole);
     fclose (kfile);
 
     if (!strcmp(g_list_nth_data(list,0),"LiVES keymap file version 2")||!strcmp(g_list_nth_data(list,0),"LiVES keymap file version 1")) update=1;
@@ -462,6 +474,7 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
     }
   }
 
+  g_free (whole);
 
   for (i=1;(keymap_file2==NULL&&i<g_list_length(list))||(keymap_file2!=NULL&&!eof);i++) {
     gchar **array;
@@ -557,6 +570,9 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
       continue;
     }
 
+    def_modes[key-1]++;
+
+
     if (strncmp(hashname,"Weed",4)||strlen(hashname)<5) {
       d_print((tmp=g_strdup_printf(_("Invalid effect %s in %s\n"),hashname,keymap_file)));
       g_free(tmp);
@@ -570,6 +586,7 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
 
     if ((mode=weed_add_effectkey(key,whashname,TRUE))==-1) {
       // could not locate effect
+      d_print((tmp=g_strdup_printf(_("Unknown effect %s in %s\n"),whashname,keymap_file)));
       notfound=TRUE;
       g_free(hashname);
       continue;
@@ -602,7 +619,7 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
 	break;
       }
       if (nparams>0) {
-	read_key_defaults(kfd,nparams,key-1,mode,version);
+	read_key_defaults(kfd,nparams,key-1,def_modes[key-1],version);
       }
     }
   }
@@ -632,6 +649,7 @@ gboolean on_load_keymap_clicked (GtkButton *button, gpointer user_data) {
     if (notfound) do_warning_dialog_with_check_transient(_("\n\nSome effects could not be located.\n\n"),0,GTK_WINDOW(rte_window));
   }
   else load_rte_defs();
+  g_free(def_modes);
 
   return FALSE;
 }
@@ -854,6 +872,10 @@ void on_params_clicked (GtkButton *button, gpointer user_data) {
   keyw=key;
   modew=mode;
   on_render_fx_pre_activate(NULL,rfx);
+
+  // record the key so we know whose parameters to record later
+  weed_set_int_value(rfx->source,"host_hotkey",key);
+
   g_object_set_data (G_OBJECT (fx_dialog[1]),"key",GINT_TO_POINTER (key));
   g_object_set_data (G_OBJECT (fx_dialog[1]),"mode",GINT_TO_POINTER (mode));
   g_object_set_data (G_OBJECT (fx_dialog[1]),"rfx",rfx);
@@ -1199,7 +1221,7 @@ GtkWidget * create_rte_window (void) {
       // fill names of our effects
       fx_idx=0;
       list=name_type_list;
-
+      
       while (list!=NULL) {
 	weed_plant_t *filter=get_weed_filter(weed_get_idx_for_hashname(g_list_nth_data(hash_list,fx_idx),FALSE));
 	if ((enabled_in_channels(filter,FALSE)>1&&!has_video_chans_in(filter,FALSE))||(weed_plant_has_leaf(filter,"host_menu_hide")&&weed_get_boolean_value(filter,"host_menu_hide",&error)==WEED_TRUE)) {
@@ -1221,11 +1243,11 @@ GtkWidget * create_rte_window (void) {
 	list = list->next;
 	fx_idx++;
       }
-
+      
       gtk_entry_set_text (GTK_ENTRY (combo_entries[idx]),(tmp=rte_keymode_get_filter_name(i+1,j)));
       g_free(tmp);
       gtk_entry_set_editable (GTK_ENTRY (combo_entries[idx]), FALSE);
-
+      
       hbox = gtk_hbox_new (FALSE, 12);
       gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
 
