@@ -14,7 +14,8 @@
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/statvfs.h>  
+#include <sys/statvfs.h>
+#include <sys/file.h>
 
 #include "main.h"
 #include "support.h"
@@ -501,7 +502,7 @@ void d_print(const gchar *text) {
     if (mainw->current_file!=mainw->last_dprint_file&&mainw->current_file!=0&&mainw->multitrack==NULL&&(mainw->current_file==-1||cfile->clip_type!=CLIP_TYPE_GENERATOR)&&!mainw->no_switch_dprint) {
       gchar *switchtext,*tmp;
       if (mainw->current_file>0) {
-	switchtext=g_strdup_printf (_ ("\n==============================\nSwitched to clip %s\n"),(tmp=g_path_get_basename(cfile->name)));
+	switchtext=g_strdup_printf (_ ("\n==============================\nSwitched to clip %s\n"),cfile->clip_type!=CLIP_TYPE_VIDEODEV?(tmp=g_path_get_basename(cfile->name)):(tmp=g_strdup(cfile->name)));
 	g_free(tmp);
       }
       else {
@@ -2204,16 +2205,13 @@ gboolean check_file(const gchar *file_name, gboolean check_existing) {
     g_free(lfile_name);
     return FALSE;
   }
-  if (check) {
-    close(check);
-    if (!exists) {
-      unlink (lfile_name);
-    }
-    g_free(lfile_name);
-    return TRUE;
+
+  close(check);
+  if (!exists) {
+    unlink (lfile_name);
   }
   g_free(lfile_name);
-  return FALSE;
+  return TRUE;
 }
 
 
@@ -2253,6 +2251,17 @@ check_dir_access (const gchar *dir) {
 }
 
 
+gboolean check_dev_busy(gchar *devstr) {
+  int ret;
+  int fd=open(devstr,O_RDONLY|O_NONBLOCK);
+  if (fd==-1) return FALSE;
+  ret=flock(fd,LOCK_EX|LOCK_NB);
+  close(fd);
+  if (ret==-1) return FALSE;
+  return TRUE;
+}
+
+
 
 void activate_url_inner(const gchar *link) {
 #ifdef HAVE_GTK_NICE_VERSION
@@ -3393,13 +3402,14 @@ void adjustment_configure(GtkAdjustment *adjustment,
 		     gdouble step_increment,
 		     gdouble page_increment,
 		     gdouble page_size) {
+  g_object_freeze_notify (G_OBJECT(adjustment));
 
 #ifdef HAVE_GTK_NICE_VERSION
   gtk_adjustment_configure(adjustment,value,lower,upper,step_increment,page_increment,page_size);
+  g_object_thaw_notify (G_OBJECT(adjustment));
   return;
 #else
 
-  g_object_freeze_notify (G_OBJECT(adjustment));
 
   adjustment->upper=upper;
   adjustment->lower=lower;
@@ -3468,3 +3478,5 @@ LIVES_INLINE GList *g_list_move_to_first(GList *list, GList *item) {
   GList *xlist=g_list_remove_link(list,item); // item becomes standalone list
   return g_list_concat(item,xlist); // concat rest of list after item
 }
+
+
